soam.workflow package
=====================

Submodules
----------

soam.workflow.anomalies module
------------------------------

.. automodule:: soam.workflow.anomalies
   :members:
   :undoc-members:
   :show-inheritance:

soam.workflow.backtester module
-------------------------------

.. automodule:: soam.workflow.backtester
   :members:
   :undoc-members:
   :show-inheritance:

soam.workflow.forecaster module
-------------------------------

.. automodule:: soam.workflow.forecaster
   :members:
   :undoc-members:
   :show-inheritance:

soam.workflow.merge\_concat module
----------------------------------

.. automodule:: soam.workflow.merge_concat
   :members:
   :undoc-members:
   :show-inheritance:

soam.workflow.slicer module
---------------------------

.. automodule:: soam.workflow.slicer
   :members:
   :undoc-members:
   :show-inheritance:

soam.workflow.store module
--------------------------

.. automodule:: soam.workflow.store
   :members:
   :undoc-members:
   :show-inheritance:

soam.workflow.time\_series\_extractor module
--------------------------------------------

.. automodule:: soam.workflow.time_series_extractor
   :members:
   :undoc-members:
   :show-inheritance:

soam.workflow.transformer module
--------------------------------

.. automodule:: soam.workflow.transformer
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: soam.workflow
   :members:
   :undoc-members:
   :show-inheritance:
